@@ -105,8 +105,6 @@ class aiServiceInstallArgBuilderMixin():
 
         # AI Service Advanced Settings
         # -----------------------------------------------------------------------------
-        # if self.getParam('aiservice_s3_provider') != "":
-        #     command += f"  --s3-provider \"{self.getParam('aiservice_s3_provider')}\"{newline}"
         if self.getParam('aiservice_s3_accesskey') != "":
             command += f"  --s3-accesskey \"{self.getParam('aiservice_s3_accesskey')}\"{newline}"
         if self.getParam('aiservice_s3_secretkey') != "":
@@ -126,6 +124,9 @@ class aiServiceInstallArgBuilderMixin():
         if self.getParam('aiservice_s3_templates_bucket') != "":
             command += f"  --s3-templates-bucket \"{self.getParam('aiservice_s3_templates_bucket')}\"{newline}"
 
+        if self.getParam('aiservice_odh_model_deployment_type') != "":
+            command += f"  --odh-model-deployment-type \"{self.getParam('aiservice_odh_model_deployment_type')}\"{newline}"
+
         if self.getParam('aiservice_watsonxai_apikey') != "":
             command += f"  --watsonxai-apikey \"{self.getParam('aiservice_watsonxai_apikey')}\"{newline}"
         if self.getParam('aiservice_watsonxai_url') != "":
