@@ -57,8 +57,9 @@ optionalParams = [
     # Dev Mode
     "artifactory_username",
     "artifactory_token",
+    # ODH
+    "aiservice_odh_model_deployment_type",
     # AI Service
-    # "aiservice_s3_provider",
     "aiservice_s3_accesskey",
     "aiservice_s3_secretkey",
     "aiservice_s3_host",
