@@ -58,13 +58,18 @@ class InstallSummarizerMixin():
             self.printParamSummary("DNS Provider", "dns_provider")
             self.printParamSummary("Certificate Issuer", "mas_cluster_issuer")
 
+            if self.getParam('ocp_ingress') != "":
+                self.printParamSummary("OCP Ingress", "ocp_ingress")
             if self.getParam('dns_provider') == "cloudflare":
                 self.printParamSummary("CloudFlare e-mail", "cloudflare_email")
                 self.printParamSummary("CloudFlare API token", "cloudflare_apitoken")
                 self.printParamSummary("CloudFlare zone", "cloudflare_zone")
                 self.printParamSummary("CloudFlare subdomain", "cloudflare_subdomain")
             elif self.getParam('dns_provider') == "cis":
-                pass
+                self.printParamSummary("CIS e-mail", "cis_email")
+                self.printParamSummary("CIS API Key", "cis_apikey")
+                self.printParamSummary("CIS CRN", "cis_crn")
+                self.printParamSummary("CIS subdomain", "cis_subdomain")
             elif self.getParam('dns_provider') == "route53":
                 pass
             elif self.getParam('dns_provider') == "":
@@ -177,6 +182,7 @@ class InstallSummarizerMixin():
                 self.printSummary("  + Utilities", "Enabled" if "utilities=" in self.getParam("mas_appws_components") else "Disabled")
                 self.printSummary("  + Workday Applications", "Enabled" if "workday=" in self.getParam("mas_appws_components") else "Disabled")
                 self.printSummary("  + AIP", "Enabled" if "aip=" in self.getParam("mas_appws_components") else "Disabled")
+                self.printSummary("  + Vegetation Management", "Enabled" if "vegm=" in self.getParam("mas_appws_components") else "Disabled")
 
                 self.printParamSummary("+ Upgrade Type", "mas_appws_upgrade_type")
 
@@ -187,8 +193,7 @@ class InstallSummarizerMixin():
                 self.printParamSummary("+ Additional Languages", "mas_app_settings_secondary_langs")
 
                 print_formatted_text(HTML("  <SkyBlue>+ Database Settings</SkyBlue>"))
-                self.printParamSummary("  + Schema", "mas_app_settings_indexspace")
-                self.printParamSummary("  + Username", "mas_app_settings_db2_schema")
+                self.printParamSummary("  + Schema", "mas_app_settings_db2_schema")
                 self.printParamSummary("  + Tablespace", "mas_app_settings_tablespace")
                 self.printParamSummary("  + Indexspace", "mas_app_settings_indexspace")
         else:
